Type: Package
Package: ggcorrplot
Title: Visualization of a Correlation Matrix using 'ggplot2'
Version: 0.2.0
Date: 2026-07-08
Authors@R: 
    c(person(given = "Alboukadel",
             family = "Kassambara",
             role = c("aut", "cre"),
             email = "alboukadel.kassambara@gmail.com"),
      person(given = "Indrajeet",
             family = "Patil",
             role = "ctb",
             email = "patilindrajeet.science@gmail.com",
             comment = c(ORCID = "0000-0003-1995-6531", Twitter = "@patilindrajeets")))
Description: The 'ggcorrplot' package can be used to visualize easily a
    correlation matrix using 'ggplot2'. It provides a solution for
    reordering the correlation matrix and displays the significance level
    on the plot. It also includes a function for computing a matrix of
    correlation p-values.
License: GPL-2
URL:
        https://www.sthda.com/english/wiki/ggcorrplot-visualization-of-a-correlation-matrix-using-ggplot2
BugReports: https://github.com/kassambara/ggcorrplot/issues
Depends: R (>= 3.3), ggplot2 (>= 3.3.6)
Imports: reshape2, stats
Suggests: testthat (>= 3.0.0), knitr, spelling, vdiffr (>= 1.0.0)
Encoding: UTF-8
Language: en-US
RoxygenNote: 7.1.0
Config/testthat/edition: 3
NeedsCompilation: no
Packaged: 2026-07-08 15:18:07 UTC; kassambara
Author: Alboukadel Kassambara [aut, cre],
  Indrajeet Patil [ctb] (ORCID: <https://orcid.org/0000-0003-1995-6531>,
    Twitter: @patilindrajeets)
Maintainer: Alboukadel Kassambara <alboukadel.kassambara@gmail.com>
Repository: CRAN
Date/Publication: 2026-07-08 16:00:02 UTC
